[−][src]Enum rusoto_imagebuilder::GetImagePolicyError
Errors returned by GetImagePolicy
Variants
CallRateLimitExceeded(String)You have exceeded the permitted request rate for the specific operation.
Forbidden(String)You are not authorized to perform the requested operation.
InvalidRequest(String)You have made a request for an action that is not supported by the service.
ResourceNotFound(String)At least one of the resources referenced by your request does not exist.
Service(String)This exception is thrown when the service encounters an unrecoverable exception.
The service is unable to process your request at this time.
Implementations
impl GetImagePolicyError[src]
pub fn from_response(
res: BufferedHttpResponse
) -> RusotoError<GetImagePolicyError>[src]
res: BufferedHttpResponse
) -> RusotoError<GetImagePolicyError>