pub enum ListContainerRecipesError {
CallRateLimitExceeded(String),
Client(String),
Forbidden(String),
InvalidPaginationToken(String),
InvalidRequest(String),
Service(String),
ServiceUnavailable(String),
}Expand description
Errors returned by ListContainerRecipes
Variants
CallRateLimitExceeded(String)
You have exceeded the permitted request rate for the specific operation.
Client(String)
These errors are usually caused by a client action, such as using an action or resource on behalf of a user that doesn't have permissions to use the action or resource, or specifying an invalid resource identifier.
Forbidden(String)
You are not authorized to perform the requested operation.
InvalidPaginationToken(String)
You have provided an invalid pagination token in your request.
InvalidRequest(String)
You have made a request for an action that is not supported by the service.
Service(String)
This exception is thrown when the service encounters an unrecoverable exception.
The service is unable to process your request at this time.
Implementations
Sourceimpl ListContainerRecipesError
impl ListContainerRecipesError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<ListContainerRecipesError>