pub struct TargetContainerRepository {
pub repository_name: String,
pub service: String,
}Expand description
The container repository where the output container image is stored.
Fields
repository_name: StringThe name of the container repository where the output container image is stored. This name is prefixed by the repository location.
service: StringSpecifies the service in which this image was registered.